@@ -13,7 +13,7 @@
  * See the GNU Library General Public License version 2 for more details
  *)
 
-(*i $Id: calendar.ml,v 1.14 2003/09/18 14:34:01 signoles Exp $ i*)
+(*i $Id: calendar.ml,v 1.21 2004/11/17 16:05:18 signoles Exp $ i*)
 
 (*S Introduction.
 
@@ -37,6 +37,8 @@ type day = Date.day = Sun | Mon | Tue | Wed | Thu | Fri | Sat
 type month = Date.month =
     Jan | Feb | Mar | Apr | May | Jun | Jul | Aug | Sep | Oct | Nov | Dec
 
+type year = int
+
 type field = [ Date.field | Time.field ]
 
 (*S Conversions. *)
@@ -54,7 +56,7 @@ let to_date x = Date.from_jd (int_of_float (from_gmt x +. 0.5))
 
 (* Return the fractional part of [x] as a time. *)
 let to_time x = 
-  let t, _ = modf (from_gmt (x +. 0.5)) in 
+  let t, _ = modf (from_gmt x +. 0.5) in 
   let i = round (t *. 86400.) in
   assert (i < 86400);
   Time.from_seconds i
@@ -75,7 +77,7 @@ let lmake ~year ?(month=1) ?(day=1) ?(hour=0) ?(minute=0) ?(second=0) () =
   make year month day hour minute second
 
 let now () = 
-  let now = Unix.gmtime (Unix.gettimeofday ()) in
+  let now = Unix.gmtime (Unix.time ()) in
   from_gmt (make 
 	      (now.Unix.tm_year + 1900) 
 	      (now.Unix.tm_mon + 1) 
@@ -116,8 +118,8 @@ let second x = Time.second (to_time x)
 
 (*S Coercions. *)
 
-let from_unixtm x = 
-  make 
+let from_unixtm x =
+  make
     (x.Unix.tm_year + 1900) (x.Unix.tm_mon + 1) x.Unix.tm_mday
     x.Unix.tm_hour x.Unix.tm_min x.Unix.tm_sec
 
@@ -131,9 +133,9 @@ let to_unixtm x =
 
 let jan_1_1970 = 2440587.5
 
-let from_unixfloat x = x +. jan_1_1970
+let from_unixfloat x = to_gmt (x /. 86400. +. jan_1_1970)
 
-let to_unixfloat x = x -. jan_1_1970
+let to_unixfloat x = (from_gmt x -. jan_1_1970) *. 86400.
 
 (*S Boolean operations on dates. *)
 
@@ -159,14 +161,16 @@ let is_am x = Time.is_am (to_time x)
 module Period = struct
   type t = { d : Date.Period.t; t : Time.Period.t }
 
-  let split x = 
-    let f, days = modf (float_of_int (Time.Period.length x.t) /. 86400.) in
-    let seconds, days = round (f *. 86400.), int_of_float days in
-    let seconds, days = 
-      if seconds < 0 then seconds + 86400, days - 1 else seconds, days
+  let split x =
+    let rec aux s =
+      if s < 86400 then 0, s else let d, s = aux (s - 86400) in d + 1, s
     in
-    assert (seconds >= 0 && seconds < 86400);
-    Date.Period.day days, Time.Period.second seconds
+    let s = Time.Period.length x.t in
+    let d, s =
+      if s >= 0 then aux s else let d, s = aux (- s) in - (d + 1), - s + 86400
+    in
+    assert (s >= 0 && s < 86400);
+    Date.Period.day d, Time.Period.second s
 
   let normalize x =
     let days, seconds = split x in
@@ -177,8 +181,8 @@ module Period = struct
   let make y m d h mn s = 
     normalize { d = Date.Period.make y m d; t = Time.Period.make h mn s }
 
-  let lmake ?(year=0) ?(month=0) ?(day=0) ?(hour=0) ?(minute=0) ?(second=0) 
-    () =
+  let lmake 
+    ?(year=0) ?(month=0) ?(day=0) ?(hour=0) ?(minute=0) ?(second=0) () =
     make year month day hour minute second
 
   let year x = { empty with d = Date.Period.year x }
@@ -201,12 +205,14 @@ module Period = struct
   let sub x y = 
     normalize { d = Date.Period.sub x.d y.d; t = Time.Period.sub x.t y.t }
 
-  let opp x = { d = Date.Period.opp x.d; t = Time.Period.opp x.t }
+  let opp x = normalize { d = Date.Period.opp x.d; t = Time.Period.opp x.t }
 
   (* Lexicographical order over the fields of the type [t].
      Yep, [Pervasives.compare] correctly works. *)
   let compare = Pervasives.compare
 
+  let equal = (=)
+
   let to_date x = x.d
 
   let from_date x = { empty with d = x }
@@ -217,6 +223,11 @@ module Period = struct
 
   let to_time x = 
     Time.Period.add (Time.Period.hour (Date.Period.nb_days x.d * 24)) x.t
+
+  let ymds x =
+    let y, m, d = Date.Period.ymd x.d in
+    y, m, d, Time.Period.to_seconds x.t
+
 end
 
 (*S Arithmetic operations on calendars and periods. *)
@@ -229,8 +240,8 @@ let split x =
   Date.from_jd d, Time.from_seconds t
 
 let unsplit d t =
- to_gmt (float_of_int (Date.to_jd d) +. 
-	   (float_of_int (Time.to_seconds t) /. 86400.)) -. 0.5
+  to_gmt (float_of_int (Date.to_jd d) +. 
+	    (float_of_int (Time.to_seconds t) /. 86400.)) -. 0.5
 
 let add x p =
   let d, t = split x in
@@ -248,5 +259,5 @@ let next x f =
   match f with
     | #Date.field as f -> unsplit (Date.next d f) t
     | #Time.field as f -> unsplit d (Time.next t f)
-      
+
 let prev x f = -. next (-. x) f
