@@ -13,7 +13,7 @@
  * See the GNU Library General Public License version 2 for more details
  *)
 
-(*i $Id: date.mli,v 1.21 2004/11/15 16:36:55 signoles Exp $ i*)
+(*i $Id: date.mli,v 1.24 2005/01/17 13:43:55 signoles Exp $ i*)
 
 (** Date operations.
 
@@ -111,8 +111,9 @@ val day_of_year : t -> int
 
 val week : t -> int
   (** Week. 
-    E.g. [week (make 2003 1 5)] returns [1]
-    and [week (make 2003 12 28)] returns [52]. *)
+    E.g. [week (make 2000 1 3)] returns [1] and [week (make 2000 1 2)] returns
+    [52]. [week (make 2003 12 28)] returns [52] and [week (make 2003 12 29)]
+    returns [1]. *)
 
 val month : t -> month
   (** Month. E.g. [month (make 2003 6 26)] returns [Jun]. *)
@@ -159,7 +160,7 @@ val to_unixtm : t -> Unix.tm
     @since 1.01 *)
 
 val from_unixtm : Unix.tm -> t
-  (** Inverse of [to_unixtm]. 
+  (** Inverse of [to_unixtm]. Assume the current time zone.
     @since 1.01 *)
 
 val to_unixfloat : t -> float
@@ -169,13 +170,18 @@ val to_unixfloat : t -> float
     @since 1.01 *)
 
 val from_unixfloat : float -> t
-  (** Inverse of [to_unixfloat]. Ignore the fractional part of the argument. 
+  (** Inverse of [to_unixfloat]. Ignore the fractional part of the argument.
+    Assume the current time zone.
     @since 1.01 *)
 
 val to_business: t -> year * int * day
   (** Return the "business week" and the day in this week respecting ISO 8601.
-    Notice that business weeks at the beginning and end of the year
-    can sometimes have year numbers which don't match the real year. 
+    Notice that business weeks at the beginning and end of the year can
+    sometimes have year numbers which don't match the real year.
+    E.g. [to_business (make 2000 1 3)] returns [2000, 1, Mon] and [to_business
+    (make 2000 1 2)] returns [1999, 52, Sun].  [to_business (make 2003 12 28)]
+    returns [2003, 52, Sun] and [to_business (make 2003 12 29)] returns [2004,
+    1, Mon].
     @since 1.09.0 *)
 
 val from_business: year -> int -> day -> t
