@@ -1,4 +1,4 @@
-(*i $Id: test_date.ml,v 1.14 2004/11/13 20:14:07 signoles Exp $ i*)
+(*i $Id: test_date.ml,v 1.16 2005/01/17 13:27:36 signoles Exp $ i*)
 
 Printf.printf "\nTests of Date:\n\n";;
 
@@ -54,12 +54,6 @@ test (century 2001 = 21) "century 2001";;
 test (millenium 2000 = 2) "millenium 2000";;
 test (millenium 2001 = 3) "millenium 2001";;
 test (easter 2003 = make 2003 4 20) "Paques 2003";;
-test (to_unixfloat (make 1970 1 1) = 0.) "to_unixfloat 1 Jan 1970";;
-test (from_unixfloat 0. = make 1970 1 1) "from_unixfloat 1 Jan 1970";;
-test (to_unixfloat (make 2004 11 13) = 1100304000.) "to_unixfloat";;
-test (from_unixfloat 1100304000. = make 2004 11 13) "to_unixfloat";;
-test (from_unixtm (to_unixtm (make 2003 7 16)) = make 2003 7 16) 
-  "from_unixtm to_unixtm = id";;
 test (Period.nb_days (Period.make 0 0 6) = 6) "Period.nb_days ok";;
 test_exn (lazy (Period.nb_days (Period.make 1 0 0))) "Period.nb_days ko";;
 test (week_first_last 21 2004 = (make 2004 5 17, make 2004 5 23)) 
@@ -68,6 +62,30 @@ test (Period.ymd (Period.make 1 2 3) = (1, 2, 3)) "Period.ymd";;
 test (nth_weekday_of_month 2004 Oct Thu 5 = make 2004 10 28) 
   "nth_weekday_of_month";;
 
+(* Unix *)
+Time_Zone.change Time_Zone.UTC;;
+test (to_unixfloat (make 1970 1 1) = 0.) "to_unixfloat 1 Jan 1970";;
+test (from_unixfloat 0. = make 1970 1 1) "from_unixfloat 0.";;
+test (to_unixfloat (make 2004 11 13) = 1100304000.) "to_unixfloat";;
+test (from_unixfloat 1100304000. = make 2004 11 13) "from_unixfloat";;
+test (from_unixtm (to_unixtm (make 2003 7 16)) = make 2003 7 16) 
+  "from_unixtm to_unixtm = id";;
+Time_Zone.change (Time_Zone.UTC_Plus (-1));;
+test (from_unixfloat 0. = make 1969 12 31) "from_unixfloat 0. (dec-)";;
+test (from_unixtm { Unix.tm_sec = 0; tm_min = 0; tm_hour = 0; tm_mday = 1; 
+		    tm_mon = 0; tm_year = 70; tm_wday = 4; tm_yday = 0; 
+		    tm_isdst = false } = make 1969 12 31) 
+  "from_unixtm (dec-)";;
+Time_Zone.change (Time_Zone.UTC_Plus 1);;
+test (from_unixfloat 1100390390. = make 2004 11 14) "from_unixfloat (dec+)";;
+test (from_unixtm { Unix.tm_sec = 0; tm_min = 0; tm_hour = 0; tm_mday = 14; 
+		    tm_mon = 10; tm_year = 104; tm_wday = 0; tm_yday = 318;
+		    tm_isdst = false } = make 2004 11 14) 
+  "from_unixtm (dec+)";;
+test (from_unixtm (to_unixtm (make 2003 7 16)) = make 2003 7 16) 
+  "from_unixtm to_unixtm = id";;
+
+
 (* to_business *)
 test (to_business (make 2003 1 1) = (2003, 1, Wed)) "to_business 1";;
 test (to_business (make 2003 12 31) = (2004, 1, Wed)) "to_business 2";;
@@ -75,6 +93,7 @@ test (to_business (make 2002 12 31) = (2003, 1, Tue)) "to_business 3";;
 test (to_business (make 2005 1 1) = (2004, 53, Sat)) "to_business 4";;
 test (to_business (make 2004 12 31) = (2004, 53, Fri)) "to_business 5";;
 test (to_business (make 2006 1 1) = (2005, 52, Sun)) "to_business 6";;
+test (to_business (make 2005 1 17) = (2005, 3, Mon)) "to_business 7";;
 (* from_business *)
 test (from_business 2003 1 Wed = make 2003 1 1) "from_business 1";;
 test (from_business 2004 1 Wed = make 2003 12 31) "from_business 2";;
@@ -82,6 +101,7 @@ test (from_business 2003 1 Tue = make 2002 12 31) "from_business 3";;
 test (from_business 2004 53 Sat = make 2005 1 1) "from_business 4";;
 test (from_business 2004 53 Fri = make 2004 12 31) "from_business 5";;
 test (from_business 2005 52 Sun = make 2006 1 1) "from_business 6";;
+test (from_business 2005 3 Mon = make 2005 1 17) "from_business 7";;
 test_exn (lazy (from_business 2005 0 Sun)) "from_business_bad 1";;
 test_exn (lazy (from_business 2005 53 Sun)) "from_business_bad 2";;
 
